SledEventTree

Struct SledEventTree 

pub struct SledEventTree<T> { /* private fields */ }
Direct singular key-value of T table

Implementations

Source

impl<T> SledEventTree<T>

pub fn new(tree: Tree) -> Self

table constructor

pub fn len(&self) -> usize

Returns size of the underlying tree

Source

impl<T> SledEventTree<T>

DB “Tables” functionality

pub fn get(&self, id: u64) -> Result<Option<T>, Error>

get entire Vec in one go

pub fn contains_key(&self, id: u64) -> Result<bool, Error>

check if sprovided u64 key is present in the db

pub fn contains_value(&self, value: &T) -> bool
where T: PartialEq,

check if value T is present in the db

pub fn insert(&self, key: u64, value: &T) -> Result<(), Error>

insert T with given key Warning! This will rewrite existing value with the same key

pub fn iter(&self) -> impl DoubleEndedIterator<Item = T>

iterator over T deserialized from the db

pub fn get_next_key(&self) -> u64

provides which u64 key to use to add NEW entry

pub fn get_key_by_value(&self, value: &T) -> Result<Option<u64>, Error>
where T: Serialize,

somewhat expensive! gets optional u64 key for given &T if present in the db

pub fn designated_key(&self, identifier: &T) -> u64
where T: Serialize,

combination of get_key_by_value() and get_next_key() also expensive… to be used when unsure if identifier is present in the db